@@ -1,2 +1,2 @@
-image_dir="${debci_data_basedir}/qemu"
+image_dir="/var/lib/debci/qemu"
 image="${image_dir}/${debci_suite}-${debci_arch}.img"
