@@ -16,7 +16,7 @@ module Debci
     belongs_to :package, class_name: 'Debci::Package'
     has_many :package_status, class_name: 'Debci::PackageStatus'
 
-    scope :newsworthy, -> { where(['status in (?) AND previous_status in (?) and status != previous_status', ['pass', 'fail', 'neutral'], ['pass', 'fail', 'neutral']]) }
+    scope :newsworthy, -> { not_pinned.where(['status in (?) AND previous_status in (?) and status != previous_status', ['pass', 'fail', 'neutral'], ['pass', 'fail', 'neutral']]) }
 
     scope :finished, -> { where('status is NOT NULL') }
 
@@ -117,6 +117,11 @@ module Debci
         job.duration_seconds = duration.read.to_i
         job.date = duration.stat.mtime
 
+        worker_file = (src / 'worker')
+        if worker_file.exist?
+          job.worker = worker_file.read.strip
+        end
+
         testpkg_version = src / 'testpkg-version'
         if testpkg_version.exist?
           job.version = testpkg_version.read.split.last if testpkg_version
@@ -227,8 +232,10 @@ module Debci
         parameters << "trigger:#{CGI.escape(trigger)}"
       end
       Array(self.pin_packages).each do |pin|
-        pkg, suite = pin
-        parameters << "pin-packages:#{suite}=#{pkg}"
+        *pkgs, suite = pin
+        pkgs.each do |pkg|
+          parameters << "pin-packages:#{suite}=#{pkg}"
+        end
       end
       parameters
     end
