@@ -17,10 +17,22 @@ describe Debci::Config do
       it "knows about #{key}" do
         expect(config.send(key)).to be_a(Array)
       end
-    elsif key == :quiet
+    elsif [:quiet, :amqp_ssl].include?(key)
       it "knows about #{key}" do
         expect(config.send(key)).to_not be_a(String)
       end
+    elsif [:data_retention_days].include?(key)
+      it "knows about #{key}" do
+        expect(config.send(key)).to be_a(Integer)
+      end
+    elsif [:failing_packages_per_page].include?(key)
+      it "knows about #{key}" do
+        expect(config.send(key)).to be_a(Integer)
+      end
+    elsif [:status_visible_days].include?(key)
+      it "knows about #{key}" do
+        expect(config.send(key)).to be_a(Integer)
+      end
     else
       it "knows about #{key}" do
         expect(config.send(key)).to be_a(String)
