@@ -32,21 +32,29 @@ describe Debci::Job do
     expect(Debci::Job.pending).to eq([job0, job1])
   end
 
-  it 'escapes trigger' do
-    job = Debci::Job.new(trigger: 'foo bar')
-    expect(job.enqueue_parameters).to_not include('trigger:foo bar')
-    expect(job.enqueue_parameters).to include('trigger:foo+bar')
-  end
+  context 'when enqueing' do
+    it 'escapes trigger' do
+      job = Debci::Job.new(trigger: 'foo bar')
+      expect(job.enqueue_parameters).to_not include('trigger:foo bar')
+      expect(job.enqueue_parameters).to include('trigger:foo+bar')
+    end
 
-  [
-    'áéíóú',
-    '`cat /etc/passwd`',
-    '$(cat /etc/passwd)',
-    "a\nb"
-  ].each do |invalid|
-    it('escapes \"%<invalid>s" in trigger' % { invalid: invalid }) do
-      job = Debci::Job.new(trigger: invalid)
-      expect(job.enqueue_parameters).to_not include(invalid)
+    [
+      'áéíóú',
+      '`cat /etc/passwd`',
+      '$(cat /etc/passwd)',
+      "a\nb"
+    ].each do |invalid|
+      it('escapes \"%<invalid>s" in trigger' % { invalid: invalid }) do
+        job = Debci::Job.new(trigger: invalid)
+        expect(job.enqueue_parameters).to_not include(invalid)
+      end
+    end
+
+    it 'handles multiple pinned packages' do
+      job = Debci::Job.new(pin_packages: [["src:foo", "src:bar", "unstable"]])
+      expect(job.enqueue_parameters).to include('pin-packages:unstable=src:foo')
+      expect(job.enqueue_parameters).to include('pin-packages:unstable=src:bar')
     end
   end
 
@@ -111,7 +119,7 @@ describe Debci::Job do
   end
 
   it 'takes ridiculously large version numbers' do
-    v = '1.' * 100 + '0'
+    v = "#{'1.' * 100}0"
     Debci::Job.create!(package: package, version: v)
   end
 
@@ -224,6 +232,7 @@ describe Debci::Job do
 
     it('returns job instance') { expect(job.id).to eq(original_job.id) }
     it('gets status') { expect(job.status).to eq('pass') }
+    it('gets worker') { expect(job.worker).to eq('ci-worker-1') }
     it('gets message') { expect(job.message).to eq('All tests passed') }
     it('gets duration') { expect(job.duration_seconds).to eq(9) }
     it('gets date') { expect(job.date).to eq(past) }
@@ -265,6 +274,7 @@ describe Debci::Job do
       FileUtils.cp_r 'spec/debci/job_spec/autopkgtest-incoming', second_incoming
       FileUtils.touch(File.join(second_incoming, 'duration'), mtime: Time.now)
       File.open(File.join(second_incoming, 'exitcode'), 'w') { |f| f.write('4') }
+      File.open(File.join(second_incoming, 'worker'), 'w') { |f| f.write('ci-worker-1') }
       File.open(File.join(second_incoming, 'testpkg-version'), 'w') { |f| f.write('foobar 99-1') }
       Debci::Job.receive(second_incoming)
     end
@@ -407,4 +417,19 @@ describe Debci::Job do
       expect(Debci::Job.new(pin_packages: [])).to_not be_pinned
     end
   end
+
+  context 'testing for newsworthiness' do
+    it 'is newsworthy on status transitions' do
+      job1 = package.jobs.create!(date: Time.now - 1.day, status: 'fail', previous_status: 'pass', suite: 'unstable', arch: 'amd64')
+      job2 = package.jobs.create!(date: Time.now, status: 'fail', previous_status: 'fail', suite: 'unstable', arch: 'amd64')
+      news = Debci::Job.newsworthy
+      expect(news).to include(job1)
+      expect(news).to_not include(job2)
+    end
+
+    it 'is not newsworthy with pinned packages' do
+      job = package.jobs.create!(date: Time.now - 1.day, status: 'fail', previous_status: 'pass', suite: 'unstable', arch: 'amd64', pin_packages: [["src:foo", "src:bar", "unstable"]])
+      expect(Debci::Job.newsworthy).to_not include(job)
+    end
+  end
 end
