@@ -2,6 +2,10 @@ if ! which checkbashisms >/dev/null 2>&1; then
   echo "SKIP: checkbashisms not available"
   exit 0
 fi
+if ! which shellcheck >/dev/null 2>&1; then
+  echo "SKIP: shellcheck not available"
+  exit 0
+fi
 
 base=$(readlink -f $(dirname $0)/..)
 
