@@ -1,9 +1,11 @@
 #!/bin/bash
 
-echo "Running as user vagrant"
+set -eux
+
 cd /vagrant
 ./tools/init-dev.sh
 make
 ./bin/debci migrate
 ./bin/debci setup-chdist
-echo "Development virtual machine is installed!"
\ No newline at end of file
+set +x
+echo "Development virtual machine is installed!"
